@@ -122,6 +122,12 @@ sub _announce {
 sub notify_parent_child_was_forked {
     my($self, $child_pid) = @_;
 
+    my $gotit = sub {
+        my($rv,$env) = @_;
+        $env->{'psgix.harakiri.commit'} = Plack::Util::TRUE;
+    };
+    $self->{router}->once_after('POST','/announce_child', $gotit);
+    $self->run();
 }
 
 # called in the child process after a fork
@@ -204,10 +210,22 @@ sub announce_child {
 sub do_eval {
     my($self, $env) = @_;
     my $req = Plack::Request->new($env);
-    my $eval_string = $DB::eval_string = $req->content();
+    my $eval_string = $req->content();
 
     my $resp = $self->_resp('evalresult', $env);
 
+    my $result_packager = sub {
+        my $data = shift;
+        $data->{expr} = $eval_string;
+        return $data;
+    };
+    return $self->_eval_plumbing_closure($eval_string,$resp, $env, $result_packager);
+}
+
+sub _eval_plumbing_closure {
+    my($self, $eval_string, $resp, $env, $result_packager) = @_;
+
+    $DB::eval_string = $eval_string;
     return sub {
         my $responder = shift;
         my $writer = $responder->([ 200, [ 'Content-Type' => 'application/json' ]]);
@@ -219,7 +237,8 @@ sub do_eval {
                 sub {
                     my $data = shift;
                     $data->{result} = $self->_encode_eval_data($data->{result}) if ($data->{result});
-                    $data->{expr} = $eval_string;
+                    $data = $result_packager->($data);
+
                     $resp->data($data);
                     $writer->write($resp->encode());
                     $writer->close();
@@ -287,6 +306,19 @@ sub loaded_files {
         ];
 }
 
+my %perl_special_vars = map { $_ => 1 }
+    qw( $0 $1 $2 $3 $4 $5 $6 $7 $8 $9 $& ${^MATCH} $` ${^PREMATCH} $'
+        ${^POSTMATCH} $+ $^N @+ %+ $. $/ $| $\ $" $; $% $= $- @-
+        %- $~ $^ $: $^L $^A $? ${^CHILD_ERROR_NATIVE} ${^ENCODING}
+        $! %! $^E $@ $$ $< $> $[ $] $^C $^D ${^RE_DEBUG_FLAGS}
+        ${^RE_TRIE_MAXBUF} $^F $^H %^H $^I $^M $^O ${^OPEN} $^P $^R
+        $^S $^T ${^TAINT} ${^UNICODE} ${^UTF8CACHE} ${^UTF8LOCALE}
+        $^V $^W ${^WARNING_BITS} ${^WIN32_SLOPPY_STAT} $^X @ARGV $ARGV
+        @F  @ARG ); # @_ );
+$perl_special_vars{q{$,}} = 1;
+$perl_special_vars{q{$(}} = 1;
+$perl_special_vars{q{$)}} = 1;
+
 # Get the value of a variable, possibly in an upper stack frame
 sub do_getvar {
     my($self, $env) = @_;
@@ -295,18 +327,30 @@ sub do_getvar {
     my $varname = $req->param('v');
 
     my $resp = $self->_resp('getvar', $env);
-    my $adjust = DB->_first_program_frame();
-    my $value = eval { DB->get_var_at_level($varname, $level + $adjust) };
 
-    if ($@) {
-        if ($@ =~ m/Can't locate PadWalker/) {
+    if ($perl_special_vars{$varname}) {
+        my $result_packager = sub {
+            my $data = shift;
+            $data->{expr} = $varname;
+            $data->{level} = $level;
+            return $data;
+        };
+        return $self->_eval_plumbing_closure($varname, $resp, $env, $result_packager);
+    }
+
+    my $adjust = DB->_first_program_frame();
+    my $value = eval { DB->get_var_at_level($varname, $level + $adjust - 1) };
+    my $exception = $@;
+
+    if ($exception) {
+        if ($exception =~ m/Can't locate PadWalker/) {
             $resp->{type} = 'error';
             $resp->data('Not implemented - PadWalker module is not available');
 
-        } elsif ($@ =m/Not nested deeply enough/) {
+        } elsif ($exception =~ m/Not nested deeply enough/) {
             $resp->data( { expr => $varname, level => $level, result => undef } );
         } else {
-            die $@;
+            die $exception
         }
     } else {
         $value = $self->_encode_eval_data($value);
