@@ -5,6 +5,8 @@ package Devel::hdb::DB;
 
 use Scalar::Util;
 
+use Devel::hdb::DB::Eval;
+
 package DB;
 
 # NOTE: Look into trapping $SIG{__DIE__} se we can report
@@ -235,38 +237,8 @@ sub _first_program_frame {
 sub get_var_at_level {
     my($class, $varname, $level) = @_;
 
-    require PadWalker;
-
-    my $h = PadWalker::peek_my( $level || 1);
-
-    unless (exists $h->{$varname}) {
-        # not a lexical, try our()
-        $h = PadWalker::peek_our( $level || 1);
-    }
-
-    unless (exists $h->{$varname}) {
-        # last chance, see if it's a package var
-
-        if (my($sigil, $bare_varname) = ($varname =~ m/^([\$\@\%\*])(\w+)$/)) {
-            # a varname without a pacakge, try in the package at
-            # that caller level
-            my($package) = caller($level+1);
-            $package ||= 'main';
-
-            my $expanded_varname = $sigil . $package . '::' . $bare_varname;
-            $expanded_varname = _fixup_expr_for_eval($expanded_varname);
-            my @value = eval( $expanded_varname );
-            return @value < 2 ? $value[0] : \@value;
-
-        } elsif ($varname =~ m/^[\$\@\%\*]\w+(::\w+)*(::)?$/) {
-            $varname = _fixup_expr_for_eval($varname);
-            my @value = eval($varname);
-            return @value < 2 ? $value[0] : \@value;
-        }
-    }
-
-    return unless exists($h->{$varname});
-    return ${ $h->{$varname} };
+    require Devel::hdb::DB::GetVarAtLevel;
+    return Devel::hdb::DB::GetVarAtLevel::get_var_at_level($varname, $level+1);
 }
 
 
@@ -418,59 +390,6 @@ sub prepare_eval {
     }
 }
 
-# This substitution is done so that we return HASH, as opposed to a list
-# An expression of %hash results in a list of key/value pairs that can't
-# be distinguished from a list.  A glob gets replaced by a glob ref.
-sub _fixup_expr_for_eval {
-    my($expr) = @_;
-
-    $expr =~ s/^\s*([%*])/\\$1/o;
-    return $expr;
-}
-
-sub eval {
-
-    local($^W) = 0;  # no warnings
-
-    $eval_string = _fixup_expr_for_eval($eval_string);
-
-    my @result;
-    {
-        # Try to keep the user code from messing  with us. Save these so that
-        # even if the eval'ed code changes them, we can put them back again.
-        # Needed because the user could refer directly to the debugger's
-        # package globals (and any 'my' variables in this containing scope)
-        # inside the eval(), and we want to try to stay safe.
-        my $orig_trace   = $trace;
-        my $orig_single  = $single;
-        my $orig_cd      = $^D;
-
-        # Untaint the incoming eval() argument.
-        { ($eval_string) = $eval_string =~ /(.*)/s; }
-
-        @result = eval "$usercontext $eval_string;\n";
-
-        # restore old values
-        $trace  = $orig_trace;
-        $single = $orig_single;
-        $^D     = $orig_cd;
-    }
-
-    my $exception = $@;  # exception from the eval
-    # Since we're only saving $@, we only have to localize the array element
-    # that it will be stored in.
-    local $saved[0];    # Preserve the old value of $@
-    eval { &DB::save };
-
-    if ($exception) {
-        return { exception => $exception };
-    } elsif (@result == 1) {
-        return { result => $result[0] };
-    } else {
-        return { result => \@result };
-    }
-}
-
 sub disable_debugger {
     # Setting $^P disables single stepping and subrouting entry
     # bug if the program sets $DB::single explicitly, it'll still enter DB()
