@@ -26,11 +26,6 @@ function Debugger(sel) {
     this.programTerminated = false;
 
     // templates
-    this.navTabTemplate = Handlebars.compile( $('#nav-tab-template').html() );
-    this.navTabContentTemplate = Handlebars.compile( $('#nav-tab-content-template').html() );
-    this.navPaneTemplate = Handlebars.compile( $('#nav-pane-template').html() );
-    this.watchedExpressionTemplate = Handlebars.compile( $('#watched-expr-template').html() );
-    this.currentSubAndArgsTemplate = Handlebars.compile( $('#current-sub-and-args-template').html() );
     Handlebars.registerHelper('ifDefined', function(val, options) {
         if ((val !== undefined) && (val !== null) && (val !== '')) {
             return options.fn(this)
@@ -41,12 +36,19 @@ function Debugger(sel) {
     Handlebars.registerPartial('breakpoint-condition-template', $('#breakpoint-condition-template').html() );
     Handlebars.registerPartial('breakpoint-action-template', $('#breakpoint-action-template').html() );
     Handlebars.registerPartial('breakpoint-right-click-template', $('#breakpoint-right-click-template').html() );
-    this.breakpointRightClickMenuTemplate = Handlebars.compile( $('#breakpoint-right-click-template').html() );
-    this.breakpointConditionTemplate = Handlebars.compile( $('#breakpoint-condition-template').html() );
-    this.breakpointActionTemplate = Handlebars.compile( $('#breakpoint-action-template').html() );
-    this.breakpointListItemTemplate = Handlebars.compile( $('#breakpoint-list-item-template').html() );
-    this.forkedChildModalTemplate = Handlebars.compile($('#forked-child-modal-template').html() );
-    this.saveLoadBreakpointsModalTemplate = Handlebars.compile($('#save-load-breakpoints-modal-template').html() );
+    this.templates = {
+        navTab: Handlebars.compile( $('#nav-tab-template').html() ),
+        navTabContent: Handlebars.compile( $('#nav-tab-content-template').html() ),
+        navPane: Handlebars.compile( $('#nav-pane-template').html() ),
+        watchedExpression: Handlebars.compile( $('#watched-expr-template').html() ),
+        currentSubAndArgs: Handlebars.compile( $('#current-sub-and-args-template').html() ),
+        breakpointRightClickMenu: Handlebars.compile( $('#breakpoint-right-click-template').html() ),
+        breakpointCondition: Handlebars.compile( $('#breakpoint-condition-template').html() ),
+        breakpointAction: Handlebars.compile( $('#breakpoint-action-template').html() ),
+        breakpointListItem: Handlebars.compile( $('#breakpoint-list-item-template').html() ),
+        forkedChildModal: Handlebars.compile($('#forked-child-modal-template').html() ),
+        saveLoadBreakpointsModal: Handlebars.compile($('#save-load-breakpoints-modal-template').html() )
+    };
 
     // The step in, over, run buttons
     this.controlButtons = $('.control-button');
@@ -214,7 +216,7 @@ function Debugger(sel) {
     this.saveLoadBreakpoints = function(e) {
         e.preventDefault();
         var isSave = $(e.currentTarget).attr('id') === 'save-breakpoints';
-        var modal = $( this.saveLoadBreakpointsModalTemplate({
+        var modal = $( this.templates.saveLoadBreakpointsModal({
                                     action: isSave ? 'Save' : 'Load',
                                     filename: this._defaultBreakpointFileName()
                         }))
@@ -278,7 +280,7 @@ function Debugger(sel) {
 
             breakpointListItem = breakpointsList.find('[data-filename="' + filename
                                                         + '"][data-lineno="' + line + '"]'),
-            newBpListItem = $(dbg.breakpointListItemTemplate(
+            newBpListItem = $(dbg.templates.breakpointListItem(
                                     $.extend({filename : filename, lineno: line}, bp_hash[line])));
 
             if (isDeleteBreakpoint && breakpointListItem.length) {
@@ -383,7 +385,7 @@ function Debugger(sel) {
             menu;
 
         $.extend(bp, { filename: filename, lineno: lineno });
-        menu = this.breakpointRightClickMenuTemplate($.extend({ filename: filename, lineno: lineno }, bp));
+        menu = this.templates.breakpointRightClickMenu($.extend({ filename: filename, lineno: lineno }, bp));
 
         if (this.breakpointPopover) {
             this.breakpointPopover.popover('destroy');
@@ -554,6 +556,12 @@ function Debugger(sel) {
         }
 
         $elt.addClass('hovered-perl-var');
+        // Is this an indexed part of a variable
+        var also = $elt.attr('data-part-of');
+        if (also) {
+            // hilite it, too
+            $elt.parent().find('[data-eval="'+also+'"]').addClass('hovered-perl-var');
+        }
         this.perlVarPopover = $elt;
         $.ajax({url: 'getvar',
                 dataType: 'json',
@@ -662,10 +670,10 @@ function Debugger(sel) {
 
         // Update the tab completely so the tooltip text will be correct
         if (tab.length === 0) {
-            tab = $( this.navTabTemplate({active: i === 0}) );
+            tab = $( this.templates.navTab({active: i === 0}) );
             tab.appendTo(tabs);
         }
-        html = this.navTabContentTemplate({ label: frame.subname,
+        html = this.templates.navTabContent({ label: frame.subname,
                                             longlabel: frame.subroutine,
                                             tabId: tabId,
                                             filename: filename,
@@ -686,7 +694,7 @@ function Debugger(sel) {
                 var codeTable = codePane.find('.program-code');
                 this.setCurrentLineForCodeTable(codeTable, line);
 
-                var current = dbg.currentSubAndArgsTemplate({  subroutine: frame.subroutine,
+                var current = dbg.templates.currentSubAndArgs({  subroutine: frame.subroutine,
                                                                 lineno: frame.line,
                                                                 subArgs: subArgs
                                                             });
@@ -697,7 +705,7 @@ function Debugger(sel) {
             return;
         }
 
-        html = this.navPaneTemplate({   tabId: tabId,
+        html = this.templates.navPane({   tabId: tabId,
                                         filename: filename,
                                         active: i === 0 });
         if (codePane.length === 0) {
@@ -724,7 +732,7 @@ function Debugger(sel) {
                 dbg.setCurrentLineForCodeTable($copy, line);
                 dbg.breakpointManager.markBreakpoints(filename, $copy);
 
-                var current = dbg.currentSubAndArgsTemplate({  subroutine: frame.subroutine,
+                var current = dbg.templates.currentSubAndArgs({  subroutine: frame.subroutine,
                                                                 lineno: frame.line,
                                                                 subArgs: subArgs
                                                             });
@@ -816,7 +824,7 @@ function Debugger(sel) {
                 alert('Already watching '+expr);
 
             } else {
-                var newExpr = $( dbg.watchedExpressionTemplate({ expr: expr }) );
+                var newExpr = $( dbg.templates.watchedExpression({ expr: expr }) );
                 dbg.watchedExpressions[expr] = newExpr;
                 if (originalExpr) {
                     // Editing a watch expr
@@ -844,7 +852,7 @@ function Debugger(sel) {
             run = data.run;
 
         //alert('Child process '+pid+' forked.  <a href="'+uri+'">Click here</a> to debug it');
-        var modal = $( this.forkedChildModalTemplate({pid: pid, uri: uri, run: run}))
+        var modal = $( this.templates.forkedChildModal({pid: pid, uri: uri, run: run}))
                         .appendTo(this.elt)
                         .modal({ backdrop: true, keyboard: true, show: true })
                         .focus();
